@@ -13,7 +13,7 @@ my $sth;#sth hub
 
 =head1 NAME
 
-Mojolicious::Plugin::RoutesAuthDBI::Admin - is a mixed Mojolicious::Controller. It invoking from plugin module and might also using as standard Mojolicious::Controller. From plugin it controll access to routes trought sintax of ->over(...), see L<Mojolicious::Routes::Route#over>
+Mojolicious::Plugin::RoutesAuthDBI::Admin - is a Mojolicious::Controller for manage admin operations on DBI tables: controllers, actions, routes, roles, users.
 
 =head1 SYNOPSIS
 
@@ -44,7 +44,7 @@ Both above options determining the module controller for web actions on tables r
     admin = > {
         namespace => 'Mojolicious::Plugin::RoutesAuthDBI',
         module => 'Admin',
-        prefix => 'admin',
+        prefix => 'admin', # lc(<module>)
         trust => $app->secrets->[0],
     },
     
